Speed up multimodule output from 22ms to 9ms

This commit is contained in:
Andre Bernet
2016-07-18 20:18:19 +02:00
parent 0a1e913ecd
commit a6ceb56dcd
+1 -1
View File
@@ -105,7 +105,7 @@ void setupPulsesMultimodule(uint8_t port)
modulePulsesData[EXTERNAL_MODULE].dsm2.serialByte = 0 ;
modulePulsesData[EXTERNAL_MODULE].dsm2.serialBitCount = 0 ;
#else
modulePulsesData[EXTERNAL_MODULE].dsm2.rest = 44000;
modulePulsesData[EXTERNAL_MODULE].dsm2.rest = 18000; // 9ms refresh
modulePulsesData[EXTERNAL_MODULE].dsm2.index = 1;
#endif